import { DataType } from "../common/DataType";
import { Mime } from "../common/Mime";
import { ObjectFieldMetadata } from "../common/ObjectFieldMetadata";
export interface VectorProps {
    /**
     * The super set of the provided value.
     */
    superSet?: any[];
    /**
     * Allow the provided vector to contain duplicated values. Default to true if omitted.
     */
    allowDuplicated?: boolean;
    /**
     * Min length of the vector. Default to be zero.
     */
    minLength?: number;
    /**
     * Max length of the vector. Default to be unlimited.
     */
    maxLength?: number;
    /**
     * Data type of the vector element.
     */
    elementDataType?: DataType;
}
export interface RangeProps {
    /**
     * Min value of the range.
     */
    min?: number;
    /**
     * Max value of the range.
     */
    max?: number;
    /**
     * If true, include min value in the range.
     */
    minExclusive?: boolean;
    /**
     * If true, include max value in the range.
     */
    maxExclusive?: boolean;
}
export interface MimeProps {
    type?: Mime;
    maxFileKB?: number;
}
export interface DtoFieldMetadata extends ObjectFieldMetadata {
    /**
     * Regex express check
     */
    regex?: string;
    /**
     * Accept null as value.
     */
    allowNull?: boolean;
    /**
     * Integral numeric value.
     */
    isIntegral?: boolean;
    /**
     * Value in range. Inclusive default to true if omitted.
     */
    rangeProps?: RangeProps;
    /**
     * Value belong to this enum.
     */
    enum?: any[];
    /**
     * The provided value is an array.
     */
    vectorProps?: VectorProps;
    /**
     * Use to validate in case DateType is Object, or in case DataType is Array and vectorProps.elementDataType is Object.
     */
    objectTypeConstructor?: any;
    /**
     * This value is generated from server and must not be supplied from client.
     */
    serverValue?: boolean;
    /**
     * This field is related to one model which has relationId as id.
     */
    relationId?: string;
    /**
     * Mime type for better client-side rendering.
     */
    mimeProps?: MimeProps;
    /**
     * Whether current field is timestamp
     */
    isTimestamp?: boolean;
    /**
     * Whether to use TEXT to store the string value at provided length.
     */
    textLength?: number;
    /**
     * Whether to store this as 64-bit big integer.
     */
    isBigInt?: boolean;
}
